==> qastools_1.1.0.orig.tar.xz: qastools-v1.1.0/shared/src/wdg/equal_columns_layout_group.cpp <==
/// QasTools: Desktop toolset for the Linux sound system ALSA.
/// \copyright See COPYING file.

#include "equal_columns_layout_group.hpp"

namespace Wdg
{

//
// Equal_Columns_Layout_Row
//
Equal_Columns_Layout_Row::Equal_Columns_Layout_Row ( unsigned int row_idx_n )
: _row_index ( row_idx_n )
{
}

Equal_Columns_Layout_Row::~Equal_Columns_Layout_Row () = default;

//
// Equal_Columns_Layout_Column
//
Equal_Columns_Layout_Column::Equal_Columns_Layout_Column (
    unsigned int column_index_n )
: _column_index ( column_index_n )
, _active_rows ( 0 )
, _column_pos ( 0 )
, _column_width ( 0 )
{
}

Equal_Columns_Layout_Column::~Equal_Columns_Layout_Column ()
{
  clear_rows ();
}

void
Equal_Columns_Layout_Column::set_column_pos ( unsigned int pos_n )
{
  _column_pos = pos_n;
}

void
Equal_Columns_Layout_Column::set_column_width ( unsigned int width_n )
{
  _column_width = width_n;
}

void
Equal_Columns_Layout_Column::clear_rows ()
{
  ::std::size_t rows = num_rows ();
  if ( rows > 0 ) {
    for ( ::std::size_t ii = 0; ii < rows; ++ii ) {
      Equal_Columns_Layout_Row * row ( _rows[ ii ] );
      if ( row != nullptr ) {
        delete row;
      }
    }
    _rows.clear ();
  }
}

void
Equal_Columns_Layout_Column::append_row ( Equal_Columns_Layout_Row * item_n )
{
  _rows.push_back ( item_n );
}

void
Equal_Columns_Layout_Column::remove_empty_rows_at_back ()
{
  ::std::size_t idx = num_rows ();
  while ( idx > 0 ) {
    --idx;
    Equal_Columns_Layout_Row * row = _rows[ idx ];
    bool remove = true;
    if ( row != nullptr ) {
      if ( row->item () != nullptr ) {
        remove = false;
      }
    }
    if ( remove ) {
      if ( row != nullptr ) {
        delete row;
      }
      _rows.pop_back ();
    } else {
      break;
    }
  }
}

//
// Equal_Columns_Layout_Column
//
Equal_Columns_Layout_Group::Equal_Columns_Layout_Group (
    unsigned int group_idx_n )
: _group_index ( group_idx_n )
, _active_columns ( 0 )
, _group_pos ( 0 )
, _group_width ( 0 )
{
}

Equal_Columns_Layout_Group::~Equal_Columns_Layout_Group ()
{
  clear_columns ();
}

void
Equal_Columns_Layout_Group::set_group_pos ( unsigned int pos_n )
{
  _group_pos = pos_n;
}

void
Equal_Columns_Layout_Group::set_group_width ( unsigned int width_n )
{
  _group_width = width_n;
}

void
Equal_Columns_Layout_Group::clear_columns ()
{
  if ( num_columns () > 0 ) {
    for ( ::std::size_t ii = 0; ii < _columns.size (); ++ii ) {
      delete _columns[ ii ];
    }
    _columns.clear ();
  }
}

void
Equal_Columns_Layout_Group::append_column (
    Equal_Columns_Layout_Column * column_n )
{
  if ( column_n != nullptr ) {
    _columns.push_back ( column_n );
  }
}

void
Equal_Columns_Layout_Group::remove_empty_columns_at_back ()
{
  ::std::size_t idx = num_columns ();
  while ( idx > 0 ) {
    --idx;
    Equal_Columns_Layout_Column * col = _columns[ idx ];
    bool remove = true;
    if ( col != nullptr ) {
      if ( col->num_rows () != 0 ) {
        remove = false;
      }
    }
    if ( remove ) {
      if ( col != nullptr ) {
        delete col;
      }
      _columns.pop_back ();
    } else {
      break;
    }
  }
}

} // namespace Wdg

==> qastools_1.2.0.orig.tar.xz: qastools-v1.2.0/shared/src/wdg/equal_columns_layout_group.cpp <==
/// QasTools: Desktop toolset for the Linux sound system ALSA.
/// \copyright See COPYING file.

#include "equal_columns_layout_group.hpp"

namespace Wdg
{

//
// Equal_Columns_Layout_Row
//
Equal_Columns_Layout_Row::Equal_Columns_Layout_Row ( unsigned int row_idx_n )
: _row_index ( row_idx_n )
{
}

Equal_Columns_Layout_Row::~Equal_Columns_Layout_Row () = default;

//
// Equal_Columns_Layout_Column
//
Equal_Columns_Layout_Column::Equal_Columns_Layout_Column (
    unsigned int column_index_n )
: _column_index ( column_index_n )
, _active_rows ( 0 )
, _column_pos ( 0 )
, _column_width ( 0 )
{
}

Equal_Columns_Layout_Column::~Equal_Columns_Layout_Column ()
{
  clear_rows ();
}

void
Equal_Columns_Layout_Column::set_column_pos ( unsigned int pos_n )
{
  _column_pos = pos_n;
}

void
Equal_Columns_Layout_Column::set_column_width ( unsigned int width_n )
{
  _column_width = width_n;
}

void
Equal_Columns_Layout_Column::clear_rows ()
{
  std::size_t rows = num_rows ();
  if ( rows > 0 ) {
    for ( std::size_t ii = 0; ii < rows; ++ii ) {
      Equal_Columns_Layout_Row * row ( _rows[ ii ] );
      if ( row != nullptr ) {
        delete row;
      }
    }
    _rows.clear ();
  }
}

void
Equal_Columns_Layout_Column::append_row ( Equal_Columns_Layout_Row * item_n )
{
  _rows.push_back ( item_n );
}

void
Equal_Columns_Layout_Column::remove_empty_rows_at_back ()
{
  std::size_t idx = num_rows ();
  while ( idx > 0 ) {
    --idx;
    Equal_Columns_Layout_Row * row = _rows[ idx ];
    bool remove = true;
    if ( row != nullptr ) {
      if ( row->item () != nullptr ) {
        remove = false;
      }
    }
    if ( remove ) {
      if ( row != nullptr ) {
        delete row;
      }
      _rows.pop_back ();
    } else {
      break;
    }
  }
}

//
// Equal_Columns_Layout_Column
//
Equal_Columns_Layout_Group::Equal_Columns_Layout_Group (
    unsigned int group_idx_n )
: _group_index ( group_idx_n )
, _active_columns ( 0 )
, _group_pos ( 0 )
, _group_width ( 0 )
{
}

Equal_Columns_Layout_Group::~Equal_Columns_Layout_Group ()
{
  clear_columns ();
}

void
Equal_Columns_Layout_Group::set_group_pos ( unsigned int pos_n )
{
  _group_pos = pos_n;
}

void
Equal_Columns_Layout_Group::set_group_width ( unsigned int width_n )
{
  _group_width = width_n;
}

void
Equal_Columns_Layout_Group::clear_columns ()
{
  if ( num_columns () > 0 ) {
    for ( std::size_t ii = 0; ii < _columns.size (); ++ii ) {
      delete _columns[ ii ];
    }
    _columns.clear ();
  }
}

void
Equal_Columns_Layout_Group::append_column (
    Equal_Columns_Layout_Column * column_n )
{
  if ( column_n != nullptr ) {
    _columns.push_back ( column_n );
  }
}

void
Equal_Columns_Layout_Group::remove_empty_columns_at_back ()
{
  std::size_t idx = num_columns ();
  while ( idx > 0 ) {
    --idx;
    Equal_Columns_Layout_Column * col = _columns[ idx ];
    bool remove = true;
    if ( col != nullptr ) {
      if ( col->num_rows () != 0 ) {
        remove = false;
      }
    }
    if ( remove ) {
      if ( col != nullptr ) {
        delete col;
      }
      _columns.pop_back ();
    } else {
      break;
    }
  }
}

} // namespace Wdg
